==> SnappEmailApiClient-0.3.11b0.zip: SnappEmailApiClient-0.3.11b0/snapp_email/endpoints/post/PostBoardLink_22Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import PostBoardLink_22
from snapp_email.datacontract.utils import export_dict, fill


class PostBoardLink_22Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, accept_type=None):
        """
        Retrieve options available for resource 'PostBoardLink_22'.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: PostBoardLink_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'post'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.post.board.link-v5.18+json',
            'Accept': 'application/vnd.4thoffice.post.board.link-v5.18+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers)
        
        return fill(PostBoardLink_22, response.json())
    
    def update(self, obj, postId, accept_type=None):
        """
        Pin/unpin post to/from a board.
        
        :param obj: Object to be persisted
        :type obj: PostBoardLink_22
        
        :param postId: 
        :type postId: 
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: PostBoardLink_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
            'postId': postId,
        }
        endpoint = 'post/{postId}'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.post.board.link-v5.18+json',
            'Accept': 'application/vnd.4thoffice.post.board.link-v5.18+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('put', endpoint, url_parameters, add_headers, data=json.dumps(data))
        
        return fill(PostBoardLink_22, response.json())

==> SnappEmailApiClient-0.3.19.zip: SnappEmailApiClient-0.3.19/snapp_email/endpoints/post/PostBoardLink_22Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import PostBoardLink_22
from snapp_email.datacontract.utils import export_dict, fill


class PostBoardLink_22Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'PostBoardLink_22'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: PostBoardLink_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'post'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.post.board.link-v5.18+json',
            'Accept': 'application/vnd.4thoffice.post.board.link-v5.18+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(PostBoardLink_22, response.json(), content_type=response.headers['Content-Type'])
    
    def update(self, obj, postId, impersonate_user_id=None, accept_type=None):
        """
        Pin/unpin post to/from a board.
        
        :param obj: Object to be persisted
        :type obj: PostBoardLink_22
        
        :param postId: 
        :type postId: 
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: PostBoardLink_22
        """
        url_parameters = {
        }
        endpoint_parameters = {
            'postId': postId,
        }
        endpoint = 'post/{postId}'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.post.board.link-v5.18+json',
            'Accept': 'application/vnd.4thoffice.post.board.link-v5.18+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('put', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id, data=json.dumps(data))
        
        return fill(PostBoardLink_22, response.json(), content_type=response.headers['Content-Type'])
